/*
 * additional magic numbers for extra drivers
 */
#ifdef CONFIG_SND_DEBUG_MEMORY

#define snd_msndpinnacle_pcm_t_magic		0xa25a3e01
#define msndmidi_t_magic			0xa25a3e02
#define pdacf_t_magic				0xa25a3f00
#define snd_usX2Y_stream_t_magic                0xa25a5e03
#define vortex_t_magic				0xa25a4001
#define bt87x_t_magic				0xa25a4100

#endif
